==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerListFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ReplicationControllerListFluent<A extends ReplicationControllerListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,ReplicationController item);
    public A setToItems(int index,ReplicationController item);
    public A addToItems(ReplicationController... items);
    public A addAllToItems(Collection<ReplicationController> items);
    public A removeFromItems(ReplicationController... items);
    public A removeAllFromItems(Collection<ReplicationController> items);
    public A removeMatchingFromItems(Predicate<ReplicationControllerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ReplicationController> getItems();
    public List<ReplicationController> buildItems();
    public ReplicationController buildItem(int index);
    public ReplicationController buildFirstItem();
    public ReplicationController buildLastItem();
    public ReplicationController buildMatchingItem(Predicate<ReplicationControllerBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ReplicationControllerBuilder> predicate);
    public A withItems(List<ReplicationController> items);
    public A withItems(ReplicationController... items);
    public Boolean hasItems();
    public ReplicationControllerListFluent.ItemsNested<A> addNewItem();
    public ReplicationControllerListFluent.ItemsNested<A> addNewItemLike(ReplicationController item);
    public ReplicationControllerListFluent.ItemsNested<A> setNewItemLike(int index,ReplicationController item);
    public ReplicationControllerListFluent.ItemsNested<A> editItem(int index);
    public ReplicationControllerListFluent.ItemsNested<A> editFirstItem();
    public ReplicationControllerListFluent.ItemsNested<A> editLastItem();
    public ReplicationControllerListFluent.ItemsNested<A> editMatchingItem(Predicate<ReplicationControllerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public ReplicationControllerListFluent.MetadataNested<A> withNewMetadata();
    public ReplicationControllerListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ReplicationControllerListFluent.MetadataNested<A> editMetadata();
    public ReplicationControllerListFluent.MetadataNested<A> editOrNewMetadata();
    public ReplicationControllerListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReplicationControllerFluent<ReplicationControllerListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<ReplicationControllerListFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}

==> kubernetes-model-core-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerListFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ReplicationControllerListFluent<A extends ReplicationControllerListFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,ReplicationController item);
    public A setToItems(int index,ReplicationController item);
    public A addToItems(ReplicationController... items);
    public A addAllToItems(Collection<ReplicationController> items);
    public A removeFromItems(ReplicationController... items);
    public A removeAllFromItems(Collection<ReplicationController> items);
    public A removeMatchingFromItems(Predicate<ReplicationControllerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ReplicationController> getItems();
    public List<ReplicationController> buildItems();
    public ReplicationController buildItem(int index);
    public ReplicationController buildFirstItem();
    public ReplicationController buildLastItem();
    public ReplicationController buildMatchingItem(Predicate<ReplicationControllerBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ReplicationControllerBuilder> predicate);
    public A withItems(List<ReplicationController> items);
    public A withItems(ReplicationController... items);
    public Boolean hasItems();
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.ItemsNested<A> addNewItem();
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.ItemsNested<A> addNewItemLike(ReplicationController item);
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.ItemsNested<A> setNewItemLike(int index,ReplicationController item);
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.ItemsNested<A> editItem(int index);
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.ItemsNested<A> editFirstItem();
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.ItemsNested<A> editLastItem();
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.ItemsNested<A> editMatchingItem(Predicate<ReplicationControllerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.MetadataNested<A> withNewMetadata();
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.MetadataNested<A> editMetadata();
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.MetadataNested<A> editOrNewMetadata();
    public io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReplicationControllerFluent<io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<io.fabric8.kubernetes.api.model.ReplicationControllerListFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}
